==> ksynaptics_0.1.2.orig.tar.gz: ksynaptics-0.1.2/ksynaptics/src/synparam.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefan Kombrink                                 *
 *   katakombi@web.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 

#ifndef __SYNPARAM_H
#define __SYNPARAM_H

//
// some TP parameters to begin with
//

#define TOUCHPADOFF                     "TouchpadOff"

#define TAPBUTTON1                      "TapButton1"
#define TAPBUTTON2                      "TapButton2"
#define TAPBUTTON3                      "TapButton3"
#define MAXTAPTIME                      "MaxTapTime"
                    
#define VERTSCROLLDELTA                 "VertScrollDelta"
#define HORIZSCROLLDELTA                "HorizScrollDelta"
#define CIRCSCROLLDELTA                 "CircScrollDelta"

#define CIRCULARSCROLLING               "CircularScrolling"
#define CIRCSCROLLTRIGGER               "CircScrollTrigger"

#define FINGERLOW                       "FingerLow"
#define FINGERHIGH                      "FingerHigh"

/*
#define LEFTEDGE                        "LeftEdge"
#define RIGHTEDGE                       "RightEdge"
#define BOTTOMEDGE                      "BottomEdge"
#define TOPEDGE                         "TopEdge"
*/

// 
// some custom parameters
//
#define SYNDAEMONTIMING                 "SynDaemonTiming"
#define SYNDAEMONOFF                    "SynDaemonOff"
#define VSCROLLEMUOFF                   "VScrollEmuOff"
#define HSCROLLEMUOFF                   "HScrollEmuOff"  
#define TAPPINGOFF                      "TappingOff"  
#define SCROLLINGMODE                   "ScrollingMode"
#define PRESSURESENSITIVITY             "PressureSensitivity"


#endif

==> ksynaptics_0.2.0.orig.tar.gz: ksynaptics-0.2.0/ksynaptics/src/synparam.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Stefan Kombrink                                 *
 *   katakombi@web.de                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
 

#ifndef __SYNPARAM_H
#define __SYNPARAM_H

//
// some TP parameters to begin with
//

#define TOUCHPADOFF                     "TouchpadOff"

#define TAPBUTTON1                      "TapButton1"
#define TAPBUTTON2                      "TapButton2"
#define TAPBUTTON3                      "TapButton3"
#define RTCORNERBUTTON              "RTCornerButton"
#define RBCORNERBUTTON              "RBCornerButton"
#define LTCORNERBUTTON              "LTCornerButton"
#define LBCORNERBUTTON              "LBCornerButton"
#define MAXTAPTIME                      "MaxTapTime"
                    
#define VERTSCROLLDELTA                 "VertScrollDelta"
#define HORIZSCROLLDELTA                "HorizScrollDelta"
#define CIRCSCROLLDELTA                 "CircScrollDelta"

#define CIRCULARSCROLLING               "CircularScrolling"
#define CIRCSCROLLTRIGGER               "CircScrollTrigger"

#define FINGERLOW                       "FingerLow"
#define FINGERHIGH                      "FingerHigh"

/*
#define LEFTEDGE                        "LeftEdge"
#define RIGHTEDGE                       "RightEdge"
#define BOTTOMEDGE                      "BottomEdge"
#define TOPEDGE                         "TopEdge"
*/

// 
// some custom parameters
//
#define SYNDAEMONTIMING                 "SynDaemonTiming"
#define SYNDAEMONOFF                    "SynDaemonOff"
#define VSCROLLEMUOFF                   "VScrollEmuOff"
#define HSCROLLEMUOFF                   "HScrollEmuOff"  
#define TAPPINGOFF                      "TappingOff"  
#define SCROLLINGMODE                   "ScrollingMode"
#define PRESSURESENSITIVITY             "PressureSensitivity"


#endif
